@@ -1,35 +1,20 @@
 #[allow(unused_imports)]
 #[allow(unused_macros)]
-#[cfg(feature = "diesel-id")]
 #[macro_use]
 pub extern crate diesel;
-
-#[cfg(feature = "diesel-id")]
-#[macro_use]
-pub extern crate diesel_derive_newtype;
-
-#[cfg(feature = "graphql")]
 pub extern crate async_graphql;
-
-pub extern crate serde;
-
 pub extern crate derive_more;
+pub extern crate diesel_derive_newtype;
+pub extern crate serde;
 
 #[macro_export]
 macro_rules! derive_id {
 	($id_newtype:item) => {
-		#[cfg_attr(feature = "graphql", derive($crate::async_graphql::NewType))]
-		#[cfg_attr(
-			not(feature = "graphql"),
-			derive($crate::derive_more::From, $crate::derive_more::Into)
-		)]
-		#[cfg_attr(
-			feature = "diesel-id",
-			derive($crate::diesel_derive_newtype::DieselNewType)
-		)]
-		#[cfg_attr(feature = "diesel-id", derive($crate::diesel::Identifiable))]
 		#[derive(
+			$crate::async_graphql::NewType,
 			$crate::derive_more::Display,
+			$crate::diesel_derive_newtype::DieselNewType,
+			$crate::diesel::Identifiable,
 			$crate::serde::Deserialize,
 			$crate::serde::Serialize,
 			Clone,
